@@ -3,7 +3,7 @@
 import sys
 import os
 import logging.handlers
-from server_distrib.server.common.variables import LOGGING_LEVEL
+from common.variables import LOGGING_LEVEL
 
 
 LOGGER = logging.getLogger('server')
